################################# libraries #################################
library (foreign)
library (car)
library (ggplot2)
library (nlme)
library (reshape)
library (lattice)
library (MASS)
library(psych)
library(pwr)
library(ggpubr)
library(dplyr)
library(lsr)
library(outliers)
library(coin)
library(lme4)

library(readxl)
library(stringr)

#adjust this to folder that contain data files
setwd("/Users/ding/Documents/R/Review")

# transfer all the output to a file.
sink("output_analysis_ReviewResults", split = "TRUE")
R.version.string
sessionInfo()
# for more information, use R.Version()

TableFull<- read.csv("TableFull.csv", header = TRUE, sep=";")
Functions<- read.csv("Functions.csv", header = TRUE, sep=";")
Assessment<- read.csv("Assessment.csv", header = TRUE, sep=";")
TargetSkills<- read.csv("TargetSkills.csv", header = TRUE, sep=";")

RawDataRound1 <- read.csv("RawDataFirstRound.csv", header = TRUE, sep = ";")
RawDataRound2 <- read.csv("RawDataSecondRound.csv", header = TRUE, sep = ";")
tableCoder1 <- read.csv("RawDataSecondRoundCoder1.csv", header = TRUE, sep = ";")
tableCoder2 <- read.csv("RawDataSecondRoundCoder2.csv", header = TRUE, sep = ";")

InitialSearch<- read_excel("InitialSearch.xlsx")
AdditionalSources<- read_excel("AdditionalSources.xlsx")
AfterAutomaticDuplicateRemoval <- read_excel("AfterAutomaticDuplicateRemoval.xlsx")
FullTextNotAvailable<- read_excel("FullTextNotAvailable.xlsx")
FullTextReviewed<- read_excel("FullTextReviewed.xlsx")
RejectFullText<- read_excel("RejectFullText.xlsx")
FinalIncludes <- read_excel("FinalIncludes.xlsx")

colnames(TargetSkills) <- c("ID","Negotiation","PublicSpeaking", "JobInterview","Communication","EyeGaze", "FacialExpression","EmotionRecognition","TeamWork", "SocialScenario","Other")
colnames(Functions) <- c("ID","Briefing","GoalSetting","Scheduling","RolePlaying","Modelling","Self-Observation","Monitoring",	"RealtimeGuidance",	"ImpartingKnowledge", "LearningByDoing", "Encouragement", "PerformanceFeedback", "LearningAssesment", "Debriefing")
colnames(Assessment) <- c("ID","Self-report",	"BehaviourObservation", "BiophysiologyMeasurement","other")

Functions$TotalFunctions<-rowSums(Functions[2:15])
FunctionsSkills_A<-data.frame(TargetSkills[,1],TableFull$Year.of.publication, TableFull$Target.Group, TableFull$Type, TargetSkills[,2:11], Functions[,2:16])
colnames(FunctionsSkills_A) <- c("ID","Year","TargetGroup","TechnologyType","Negotiation","PublicSpeaking", "JobInterview","Communication","EyeGaze", "FacialExpression","EmotionRecognition","TeamWork", "SocialScenario","Other","Briefing","GoalSetting","Scheduling","RolePlaying","Modelling","Self-Observation","Monitoring",	"RealtimeGuidance",	"ImpartingKnowledge", "LearningByDoing", "Encouragement", "PerformanceFeedback", "LearningAssesment", "Debriefing","TotalFunctions")


#################################################################################

cat("\n###### Reliability check of two coders for filtering process ######\n")
cat("### Refer to Section 2.1 Search procedure ######\n")

RawDataRound1$Coder1<-as.factor(RawDataRound1$Coder1)
RawDataRound1$Coder2<-as.factor(RawDataRound1$Coder2)
cat("\n## The reliability check for the first round filtering, the agreement is:",agree(RawDataRound1[2:3])$value/100,"\n")
#agree(RawDataRound1[2:3])

RawDataRound2$Coder1<-as.factor(RawDataRound2$Coder1)
RawDataRound2$Coder2<-as.factor(RawDataRound2$Coder2)
cat("\n## The reliability check for the second round filtering, the agreement is:", agree(RawDataRound2[2:3])$value/100,"\n")

cat("\n###### The results of the search and filtering process ######\n")
cat("### Refer to Section 2.1 Search procedure and PRISMA-Diagram ######\n")

cat("\n## The search resulted in a total of",NROW(InitialSearch), "conference papers, journal articles, and book chapters. Reference lists of the included papers were checked for potential papers; it resulted in", NROW(AdditionalSources) ,"further papers. After automatically removing the duplicates,", NROW(AfterAutomaticDuplicateRemoval), "papers remained for further selection.\n")
cat("\n## After the first round screening on title and abstract",NROW(AfterAutomaticDuplicateRemoval)-NROW(FullTextReviewed),"was removed.", NROW(FullTextReviewed) ,"papers remained for the second screening based on the full text.\n")
cat("\n## After the second round screening on full text",NROW(RejectFullText),"was removed that include",NROW(FullTextNotAvailable),"papers cannot find the full-text version.", NROW(FinalIncludes) ,"papers remained for the further coding.\n")

cat("\n###### Analysis for the basic information of the studies and systems ######\n")
cat("### Refer to Section 3.1 Systems, versions and basic attributes ######\n")

cat("\n## In total, the review identified",NROW(TableFull),"studies describing",NROW(TableSystem), "systems.\n")

# NROW(TableFull[grep("#", TableFull$Name), ]) 
# NROW(TableFull[grep("#1", TableFull$Name), ])
# NROW(TableFull[grep("#2", TableFull$Name), ])

NSystemsNoVersion<-NROW(TableSystem)-NROW(TableFull[grep("#", TableFull$Name), ])
NSystems<-NSystemsNoVersion+NROW(TableFull[grep("#1", TableFull$Name), ])
cat("\n## Systems had",NROW(TableSystem)/NSystems, "versions on average, while more than", NSystemsNoVersion/NSystems, "% only had one version.\n")

cat("\n###### Analysis for the tendency of the number of published studies over time  ######\n")
cat("### Refer to Figure 3: Distribution of records over the years\n")
bar_AllStudies<-ggplot(TableFull, aes(TableFull$Year.of.publication))
bar_AllStudies +geom_bar(fill = "#619CFF")+labs(x="Year", y="Number of studies")+scale_x_continuous(breaks = seq(min(TableFull$Year.of.publication), max(TableFull$Year.of.publication), by = 2))+theme(axis.text.x = element_text(face="bold",angle=45,size=14),axis.text.y = element_text(face="bold",size=14),axis.title.x = element_text(size = 15, face = "bold"), axis.title.y = element_text(size = 15, face = "bold"))


VRStudies<-subset(TableFull,TableFull$Type=="3b"|TableFull$Type=="1" )
VRStudies<- VRStudies[c("Type","Year.of.publication")] %>% group_by(Year.of.publication,Type) %>% dplyr::summarise(., studiesNumber=n())
cat("### Refer to Figure 4: Evolution of immersive VR vs Virtual Environments\n")
bar_VRStudies<-ggplot(VRStudies, aes(VRStudies$Year.of.publication,studiesNumber, fill=Type))
bar_VRStudies+stat_summary(fun.y = mean, geom="bar",position = position_dodge2(preserve = "single"))+labs(x="Year", y="Number of studies")+scale_x_continuous(breaks = seq(min(VRStudies$Year.of.publication), max(VRStudies$Year.of.publication), by = 1))+scale_fill_discrete(labels = c("Immersive virtual reality", "Screen-based virtual environment"))+theme(legend.position = "bottom",legend.box = "vertical",legend.text=element_text(size=14),legend.title = element_text(size = 15))+theme(axis.text.x = element_text(face="bold",angle=45,size=14),axis.text.y = element_text(face="bold",size=14),axis.title.x = element_text(size = 15, face = "bold"), axis.title.y = element_text(size = 15, face = "bold"))


cat("\n###### Analysis for applied technology ######\n")
cat("### Refer to Table 1: Applied technology and Section 3.2 Technologies applied and target group ######\n")

TableSystem<-TableFull[-c(6, 9, 30, 34, 51, 52, 53, 54, 67), ]
RowNumberIVR<-NROW(subset(TableSystem,TableSystem$Type=="1"))
cat("\n## The number of the systems that apply technology of immersive VR is:",RowNumberIVR)
cat("\nThe percentage is (%):",RowNumberIVR/NROW(TableSystem)*100,"\n")

RowNumberRobot<-NROW(subset(TableSystem,TableSystem$Type=="2"))
cat("\n## The number of the systems that apply technology of Robot is:",RowNumberRobot)
cat("\nThe percentage is (%):",RowNumberRobot/NROW(TableSystem)*100,"\n")

RowNumberSG<-NROW(subset(TableSystem,TableSystem$Type=="3a"))
cat("\n## The number of the systems that apply technology of serious game is:",RowNumberSG)
cat("\nThe percentage is (%):",RowNumberSG/NROW(TableSystem)*100,"\n")

RowNumberVE<-NROW(subset(TableSystem,TableSystem$Type=="3b"))
cat("\n## The number of the systems that apply technology of virtual environment is:",RowNumberVE)
cat("\nThe percentage is (%):",RowNumberVE/NROW(TableSystem)*100,"\n")

RowNumberVM<-NROW(subset(TableSystem,TableSystem$Type=="3c"))
cat("\n## The number of the systems that apply technology of video modelling is:",RowNumberVM)
cat("\nThe percentage is (%):",RowNumberVM/NROW(TableSystem)*100,"\n")

RowNumberOther<-NROW(subset(TableSystem,TableSystem$Type=="3d"))
cat("\n## The number of the systems that apply the other technologies is:",RowNumberOther)
cat("\nThe percentage is (%):",RowNumberOther/NROW(TableSystem)*100,"\n")

RowNumberScreenBased<-RowNumberOther+RowNumberVM+RowNumberVE+RowNumberSG
cat("\n## The number of the systems that apply the screen-based is:",RowNumberScreenBased)
cat("\nThe percentage is (%):",RowNumberScreenBased/NROW(TableSystem)*100,"\n")

cat("\n###### Analysis for target group ######\n")
cat("### Refer to Table 1: Target group  and Section 3.2 Technologies applied and target group ######\n")

j<-1
while(j<=4)
{
  cat("\n##",j,"The number of the systems that target", if(j==1){"illness"} else if(j==2){"healthcare professional"} else if(j==3){"general population"} else{"other"}, "is:", RowNumber<-NROW(TableSystem[TableSystem$Target.Group==j,]))
  #print(RowNumber<-NROW(TableSystem[TableSystem$Target.Group==j,]))
  cat("\nThe percentage is (%):",RowNumber/NROW(TableSystem)*100,"\n")
  #print(RowNumber/NROW(TableSystem)*100)
  j<-j+1
}

# NROW(TableSystem[grep("HFA", TableSystem$Demographics), ])
# NROW(TableSystem[grep("ASD", TableSystem$Demographics), ])
# NROW(TableSystem[grep("autistic", TableSystem$Demographics), ])
# NROW(TableSystem[grep("Autism", TableSystem$Demographics), ])
# NROW(TableSystem[grep("Schizophrenia", TableSystem$Demographics), ])

cat("\n## Among the systems that target people with a specific medical or psychological disorders",RowNumberAutism<-NROW(TableSystem[grep("HFA", TableSystem$Demographics), ])+NROW(TableSystem[grep("ASD", TableSystem$Demographics), ])+NROW(TableSystem[grep("autistic", TableSystem$Demographics), ])+NROW(TableSystem[grep("Autism", TableSystem$Demographics), ]), "systems aimed at people on the autism spectrum. The percent is:", RowNumberAutism/NROW(TableSystem[TableSystem$Target.Group==1,]), "\n")

#NROW(TableSystem[grep("Children", TableSystem$Demographics), ])
TableSystemTargetChildren<-TableSystem[grep("Children", TableSystem$Demographics), ]
TableSystemTargetchildren<-TableSystem[grep("children", TableSystem$Demographics), ]
TableSystemTargetKids<-TableSystem[grep("Kids", TableSystem$Demographics), ]
TableSystemTargetkids<-TableSystem[grep("kids", TableSystem$Demographics), ]
cat("\n## Among the systems that target people with a specific medical or psychological disorders", RowNumberChildren<-NROW(TableSystemTargetChildren[TableSystemTargetChildren$Target.Group==1,])+NROW(TableSystemTargetchildren[TableSystemTargetchildren$Target.Group==1,])+NROW(TableSystemTargetKids[TableSystemTargetKids$Target.Group==1,])+NROW(TableSystemTargetkids[TableSystemTargetkids$Target.Group==1,]), "systems target children. The percent is:",RowNumberChildren/NROW(TableSystem[TableSystem$Target.Group==1,]), "\n")


cat("\n###### Analysis for target social skills ######\n")
cat("### Refer to Table 1: Target Social skills and Section 3.3 Target skills ######\n")

TargetSkillsSystem<-TargetSkills[-c(6, 9, 30, 34, 51, 52, 53, 54, 67), ]

k<-2
while(k<=11)
{
  cat("\n##",k-1,"The number of the systems that target", if(k==2){"Negotiation"} else if(k==3){"Public speaking"} else if(k==4){"Job Interviews"}else if(k==5){"Communication"}else if(k==6){"Eye-gaze movement/eye contact"}else if(k==7){"Facial expression"}else if(k==8){"Emotion/facial recognition and body language recognition"}else if(k==9){"Teamwork/shared decision making"}else if(k==10){"Social scenario handling"} else{"Other"}, "is:",RowNumberSkills<-NROW(TargetSkillsSystem[TargetSkillsSystem[k]==1,]))
  #print(RowNumberSkills<-NROW(TargetSkillsSystem[TargetSkillsSystem[k]==1,]))
  cat("\nThe percentage is (%):",RowNumberSkills/NROW(TargetSkillsSystem)*100,"\n")
  #print(RowNumberSkills/NROW(TargetSkillsSystem)*100)
  k<-k+1
}

### Micro/Macro Skills ###
m<-1
while(m<=3)
{
  cat("\n##",m,"The number of the systems that target", if(m==1){"micro skills"} else if(m==2){"macro skills"} else{"combination of macro and micro skills"}, "is:",RowNumberSkillsLevel<-NROW(TableSystem[TableSystem$Micro.Macro==m,]))
  #print(RowNumberSkillsLevel<-NROW(TableSystem[TableSystem$Micro.Macro==m,]))
  cat("\nThe percentage is (%):",RowNumberSkillsLevel/NROW(TableSystem)*100,"\n")
  #print(RowNumberSkillsLevel/NROW(TableSystem)*100)
  m<-m+1
}

###### Analysis for the level of autonomy ######
cat("\n###### Analysis for the level of autonomy ######\n")
cat("\nRefer to Table 1: Level of Autonomy ######\n")

RowNumberWOZ<-NROW(subset(TableSystem,TableSystem$Level.of.autonomy=="1"))
cat("\n## The number of the systems that apply the wizard of oz is:", RowNumberWOZ)
cat("\nThe percentage is:",RowNumberWOZ/NROW(TableSystem)*100, "\n")

RowNumberAdaptive<-NROW(subset(TableSystem,TableSystem$Level.of.autonomy=="2"))
cat("\n## The number of the systems that apply the adaptive scripts is:",RowNumberAdaptive)
cat("\nThe percentage is:",RowNumberAdaptive/NROW(TableSystem)*100,"\n")

RowNumberFixed<-NROW(subset(TableSystem,TableSystem$Level.of.autonomy=="3"))
cat("\n## The number of the systems that apply the fixed scripts is:",RowNumberFixed)
cat("\nThe percentage is:",RowNumberFixed/NROW(TableSystem)*100,"\n")

RowNumberOther<-NROW(subset(TableSystem,TableSystem$Level.of.autonomy=="4"))
cat("\n## The number of the systems that apply other is:",RowNumberOther)
cat("\nThe percentage is:",RowNumberOther/NROW(TableSystem)*100,"\n")

cat("\n###### Analysis for functions ######\n")
cat("\n### Refer to Table 1: Functions and Section 3.4 Size and Functions ######\n")

FunctionsSkills_A<-FunctionsSkills_A[-c(6, 9, 30, 34, 51, 52, 53, 54, 67), ]
cat("\n## The average number of the functions provided by the systems is:",describe(FunctionsSkills_A$TotalFunctions)$mean, "with with standard deviation",describe(FunctionsSkills_A$TotalFunctions)$sd ,", ranging from",describe(FunctionsSkills_A$TotalFunctions)$min, "to", describe(FunctionsSkills_A$TotalFunctions)$max )
#describe(FunctionsSkills_A$TotalFunctions)

nFunctions<-15
while(nFunctions<=28)
{
  cat("\n##",nFunctions-14,"The number of the systems that provide the function of", if(nFunctions==15){"Briefing"} else if(nFunctions==16){"Goal setting"} else if(nFunctions==17){"Scheduling"}else if(nFunctions==18){"Role playing"}else if(nFunctions==19){"Modelling"}else if(nFunctions==20){"Self-Observation"}else if(nFunctions==21){"Monitoring"}else if(nFunctions==22){"Real-time guidance"}else if(nFunctions==23){"Imparting knowledge and providing instructions"} else if(nFunctions==24){"Learning by doing"} else if(nFunctions==25){"Encouragement, praise and rewarding"} else if(nFunctions==26){"Performance feedback and reflection"} else if(nFunctions==27){"Learning assessment"} else{"Debriefing"}, "is:",RowNumberFunctions<-NROW(FunctionsSkills_A[FunctionsSkills_A[nFunctions]==1,]))
  #print(RowNumberFunctions<-NROW(FunctionsSkills_A[FunctionsSkills_A[nFunctions]==1,]))
  cat("\nThe percentage is (%):",RowNumberFunctions/NROW(FunctionsSkills_A)*100,"\n")
  #print(RowNumberFunctions/NROW(FunctionsSkills_A)*100)
  nFunctions<-nFunctions+1
}


FunctionsPlusSkills<-FunctionsSkills_A[FunctionsSkills_A$Negotiation==1,][c(1,2,3,4,29)]
FunctionsPlusSkills$Skills<-1
i<-6
while (i <= 14) {
  FunctionsSkillsFormalized<-FunctionsSkills_A[FunctionsSkills_A[i]==1,][c(1,2,3,4,29)]
  FunctionsSkillsFormalized$Skills<-i-4
  FunctionsPlusSkills<-rbind(FunctionsPlusSkills,FunctionsSkillsFormalized)
  i<-i+1
}
FunctionsPlusSkills$Skills<-factor(FunctionsPlusSkills$Skills)
TotalFunctions<-describeBy(FunctionsPlusSkills,FunctionsPlusSkills$Skills)
cat("\n## From the perspective of the target skill, the systems target facial expression were designed with the largest number of functions, the average functions number is",TotalFunctions$`6`$mean[c(5)],"with standard deviation",TotalFunctions$`6`$sd[c(5)],"\n")

### Functions~TargetGroup ###
FunctionsSkills_A$TargetGroup<-factor(FunctionsSkills_A$TargetGroup)
TotalFunctionsForTargetGroup<-describeBy(FunctionsSkills_A,FunctionsSkills_A$TargetGroup)
cat("\n## From the perspective of the target group, the average number of functions provided by systems targeting clinical population, health-care professional, and the general population was", TotalFunctionsForTargetGroup$`1`$mean[c(29)], ",", TotalFunctionsForTargetGroup$`2`$mean[c(29)], ",", TotalFunctionsForTargetGroup$`3`$mean[c(29)],"\n")
cat("\nThe systems targeting the other population provide average",TotalFunctionsForTargetGroup$`4`$mean[c(29)],"functions with standard deviation",TotalFunctionsForTargetGroup$`4`$sd[c(29)],"\n")

### Functions~TechnologyType ###
TotalFunctionsForTechnologyType<-describeBy(FunctionsSkills_A,FunctionsSkills_A$TechnologyType)
cat("\n## From the perspective of the target group, the systems employing video modelling technology were designed with the largest number of functions, the average functions number is",TotalFunctionsForTechnologyType$`3c`$mean[c(29)],"with standard deviation",TotalFunctionsForTechnologyType$`3c`$sd[c(29)],"\n")


cat("\n###### Analysis for assessment ######\n")
cat("### Refer to Table 1: Assessment and Section 3.5.1 Assessment ######\n")
nAssessment<-2
while(nAssessment<=5)
{
  cat("\n##",nAssessment-1,"The number of the studies that used", if(nAssessment==2){"self-reporting"} else if(nAssessment==3){"behavioural observations"} else if(nAssessment==4){"biophysiology measurement"} else{"other"}, "as the assessment method is:",RowNumberAssessment<-NROW(Assessment[Assessment[nAssessment]==1,]))
  #print(RowNumberAssessment<-NROW(Assessment[Assessment[nAssessment]==1,]))
  cat("\nThe percentage is (%):",RowNumberAssessment/NROW(Assessment)*100, "\n")
  #print(RowNumberAssessment/NROW(Assessment)*100)
  nAssessment<-nAssessment+1
}

cat("\n###### Analysis for quasi-experiment ######\n")
cat("### Refer to Section 3.5.2 Experimental design ######\n")

RowNumberRandom<-NROW(TableFull[TableFull$Randomized.Controlled.trial==0,])
cat("\n## The number of the studies that include a quasi-experiment is (%):",RowNumberRandom)
cat("\nThe percentage is (%):",RowNumberRandom/NROW(TableFull)*100,"\n")
#RowNumberRandom/NROW(TableFull)*100

cat("\n###### Analysis for follow-up measurement ######\n")
RowNumberFollow<-NROW(subset(TableFull,TableFull$FollowUp..weeks.==0))
cat("\n## The number of the studies that include a follow-up measurement is:",RowNumberFollow)
cat("\nThe percentage is (%):",RowNumberFollow/NROW(TableFull)*100,"\n")

RowNumberWithoutFollow<-NROW(subset(TableFull,TableFull$FollowUp..weeks.!=0))
cat("\n## The number of the studies that include a follow-up measurement is:",RowNumberWithoutFollow)
cat("\nThe percentage is (%):",RowNumberWithoutFollow/NROW(TableFull)*100,"\n")

TableFull$FollowUp..weeks.<-as.numeric(as.character(TableFull$FollowUp..weeks.))
RowNumberFollowUp<-NROW(subset(TableFull,TableFull$FollowUp..weeks.<=4 & TableFull$FollowUp..weeks.>0))
cat("\n## The number of the studies that include a follow-up measurement within four weeks is:",RowNumberFollowUp,"\n")
cat("\nThe percentage is (%):",RowNumberFollowUp/(NROW(TableFull)-RowNumberFollow)*100,"\n")


RowNumberFollowUpYear<-NROW(subset(TableFull,TableFull$FollowUp..weeks.>=24))
cat("\n## The number of the studies that include a follow-up measurement after more than half a year is:",RowNumberFollowUpYear,"\n")
cat("\nThe percentage is (%):",RowNumberFollowUpYear/(NROW(TableFull)-RowNumberFollow)*100,"\n")

cat("\n###### Analysis for sample size of the experiment in the studies ###### \n")
TableFull$Total<- as.numeric(as.character(TableFull$Total))
TableFull$N.condition<- as.numeric(as.character(TableFull$N.condition))

cat("\n## The average sample size of the studies is:",describe(TableFull$Total)$mean, ",ranging from",describe(TableFull$Total)$min, "to", describe(TableFull$Total)$max,"\n")
cat("\n## The average sample size of the studies with a single-group design is:", describe(TableFull$N.condition[TableFull$Experimental.design=="4"])$mean,"\n")
cat("\n## The average sample size of the studies with a comparison or control group is:", describe(TableFull$N.condition[TableFull$Experimental.design!="4"])$mean,"\n")

TableSingle<-subset(TableFull,TableFull$Experimental.design=="4")
TableCondition<-subset(TableFull,TableFull$Experimental.design!="4")

cat("\n## Taking a group size of 28 and 26 as the cutoff for a single-group design and multi-group design respectively:")
TableSingleGroup<-describe(TableSingle$N.condition[TableSingle$N.condition > 28])
cat("\n## For a single-group design, only",TableSingleGroup$n/NROW(TableSingle)*100,"% had an adequate sample size\n")

TableConditionGroup<-describe(TableCondition$N.condition[TableCondition$N.condition > 26])
cat("\n## For a multi-group design, only",TableConditionGroup$n/NROW(TableCondition)*100,"% had an adequate sample size\n")

cat("\n###### Analysis for the experimental control ######\n")
cat("\n### Refer to Table 1: experimental control ######\n")

RowNumberAbsense<-NROW(subset(TableFull,TableFull$Experimental.design=="1"))
cat("\n## The number of the systems that apply the design of absence of intervention is:", RowNumberAbsense,"\n")
cat("The percentage is:",RowNumberAbsense/NROW(TableFull)*100,"\n")

RowNumberAlternative<-NROW(subset(TableFull,TableFull$Experimental.design=="2"))
cat("\n## The number of the systems that apply the design of comparision to alternative is:", RowNumberAlternative,"\n")
cat("The percentage is:",RowNumberAlternative/NROW(TableFull)*100,"\n")

RowNumberTD<-NROW(subset(TableFull,TableFull$Experimental.design=="3"))
cat("\n## The number of the systems that apply the design of comparision to TD is:", RowNumberTD,"\n")
cat("The percentage is:",RowNumberTD/NROW(TableFull)*100,"\n")

RowNumberSingle<-NROW(subset(TableFull,TableFull$Experimental.design=="4"))
cat("\n## The number of the systems that apply the design of single group is:", RowNumberSingle,"\n")
cat("The percentage is:",RowNumberSingle/NROW(TableFull)*100,"\n")

cat("\n###### Analysis for the results of the experiment ###### \n")
cat("\n### Refer to Table 1: Results of experiment and Section 3.5.3 Results of experiments ######\n")

RowNumberPostive<-NROW(subset(TableFull,TableFull$Postive.Result==1|TableFull$N..result==1))
cat("\n##",RowNumberPostive/NROW(TableFull)*100,"% of the studies suggested that the system had a positive impact.\n")

RowNumberSignificant<-NROW(subset(TableFull,TableFull$Postive.Result==1))
cat("\n##",RowNumberSignificant,"studies report a statistically significant positive or improvement result. The percentage is", RowNumberSignificant/NROW(TableFull)*100, "%.\n")

RowNumberPromise<-NROW(subset(TableFull,TableFull$N..result==1))
cat("\n##",RowNumberPromise,"studies indicated the system shows promise without underlying hypothesis testing support. The percentage is", RowNumberPromise/NROW(TableFull)*100, "%.\n")

RowNumberNegtative<-NROW(subset(TableFull,(TableFull$N..result==0&TableFull$Postive.Result==0)))
cat("\n##",RowNumberNegtative,"studies reported negative results. The percentage is", RowNumberNegtative/NROW(TableFull)*100, "%.\n")

RowNumberNegtativeWithRCT<-NROW(subset(TableFull,(TableFull$N..result==0&TableFull$Postive.Result==0&TableFull$Randomized.Controlled.trial==1)))
cat("\n## Among the studies reported negative results,",RowNumberNegtativeWithRCT,"studies based on statistical hypothesis testing. The percentage is", RowNumberNegtativeWithRCT/NROW(TableFull)*100, "%.\n")

RowNumberSignificantWithRCT<-NROW(subset(TableFull,TableFull$Postive.Result==1&TableFull$Randomized.Controlled.trial==1))
cat("\n## Of the studies that had a randomized controlled trial design,", RowNumberSignificantWithRCT,"studies reported statistically significant positive or improvement results. The percentage is", RowNumberSignificantWithRCT/NROW(subset(TableFull,TableFull$Randomized.Controlled.trial==1))*100, "%.\n")

######### stop redireting output.
sink()
cat("\nOutput of the analysis can be found back in file output_analysis_ReviewResults.txt")



